SystemOrganization addCategory: #ConfigurationOfCharacterMap!

Object subclass: #ConfigurationOfCharacterMap
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCharacterMap'!

!ConfigurationOfCharacterMap commentStamp: '<historical>' prior: 0!
(ConfigurationOfCharacterMap project version: #stable) load!

!ConfigurationOfCharacterMap class methodsFor: 'private' stamp: 'StephaneDucasse 2/16/2013 20:34'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfCharacterMap class methodsFor: 'catalog' stamp: 'StephaneDucasse 8/24/2013 13:56'!
catalogChangeLog

	^ 'Quite stable since a while'! !

!ConfigurationOfCharacterMap class methodsFor: 'catalog' stamp: 'StephaneDucasse 8/24/2013 13:34'!
catalogDescription

	^ 'Character map is a special kind of collection dedicated to characters. It is used by XML tools such as XMLWriter.'! !

!ConfigurationOfCharacterMap class methodsFor: 'catalog' stamp: 'StephaneDucasse 8/24/2013 14:00'!
catalogKeyClassesAndExample

	^ '==CharacterMap== is the class to look at. This class behaves like Dictionary but is tailored to the specific usecase of mapping Character objects to other objects. That means its keys must be Character objects, but its values can be any kind of object except nil. Only characters within the Unicode range of 0 to 0x10FFFF can serve as keys. It can outperform a Dictionary for lookup and insertion, but is significantly slower for anything that relies on enumeration, and it generally uses much more memory.
'! !

!ConfigurationOfCharacterMap class methodsFor: 'catalog' stamp: 'StephaneDucasse 8/24/2013 13:34'!
catalogKeyWords

	^ #(Collection Container Map Character)! !

!ConfigurationOfCharacterMap class methodsFor: 'private' stamp: 'StephaneDucasse 2/16/2013 20:34'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfCharacterMap class methodsFor: 'metacello tool support' stamp: 'StephaneDucasse 2/16/2013 20:34'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCharacterMap class methodsFor: 'metacello tool support' stamp: 'StephaneDucasse 2/16/2013 20:34'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfCharacterMap class methodsFor: 'loading' stamp: 'StephaneDucasse 2/16/2013 20:34'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfCharacterMap class methodsFor: 'loading' stamp: 'StephaneDucasse 2/16/2013 20:34'!
loadDefault
	"self loadDefault"

	^ self loadMostRecentCoreWithTests! !

!ConfigurationOfCharacterMap class methodsFor: 'loading' stamp: 'StephaneDucasse 2/16/2013 20:34'!
loadMostRecentCoreWithTests
	^self project lastVersion load: #('Core' 'Tests')! !

!ConfigurationOfCharacterMap class methodsFor: 'metacello tool support' stamp: 'StephaneDucasse 2/16/2013 20:34'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfCharacterMap class methodsFor: 'accessing' stamp: 'StephaneDucasse 2/16/2013 20:34'!
project

	^self new project! !

!ConfigurationOfCharacterMap class methodsFor: 'unloading Metacello' stamp: 'StephaneDucasse 2/16/2013 20:34'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfCharacterMap methodsFor: 'baselines' stamp: 'StephaneDucasse 2/16/2013 20:39'!
baseline100: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://smalltalkhub.com/mc/Pharo/CharacterMap/main'.	
		spec description: 'Imported from SqueakSource'.
		spec package: 'Collections-CharacterMap'.
			
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Collections-CharacterMap')
			";
			group: 'Tests' with: #('Collections-Tests-OrderPreservingDictionary'). "].! !

!ConfigurationOfCharacterMap methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 2/16/2013 20:34'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'
! !

!ConfigurationOfCharacterMap methodsFor: 'accessing' stamp: 'StephaneDucasse 2/16/2013 20:34'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfCharacterMap methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 2/16/2013 20:34'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0'.
	! !

!ConfigurationOfCharacterMap methodsFor: 'versions' stamp: 'StephaneDucasse 2/16/2013 20:38'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'Latest versions from Squeaksource'.
		
		spec package: 'Collections-CharacterMap' with: 'Collections-CharacterMap-JAAyer.2'.
		]
	

! !
